import matplotlib as mpl
import numpy as np

from matplotlib import pyplot as plt

q = mpl.rc_params_from_file('matplotlibrc')
mpl.rcParams.update(q)
mpl.rcParams.update({'text.usetex': True})

h1, ax1 = plt.subplots(figsize=(3.25, 3))
h2, ax2 = plt.subplots(figsize=(3.25, 3))
axs = [ax1, ax2]
colors = np.array([
    [[0, 0.3, 0], [0.5, 0, 0]],
    [[0, 0.25, 0.75], [0.25, 0, 0.25]],
])
lss = [(0, (4, 1,)), '-']
for LL in [10, 20, 30, 40]:
    for ii, opt in enumerate(['pm', 'cb']):
        for jj in [1, 2]:
            f, strain = np.loadtxt('../strain/ce{}_{}km_{}.txt'.format(jj, LL, opt), unpack=1)
            axs[jj-1].loglog(
                f,
                strain,
                lw = LL // 10,
                ls = lss[ii],
                c = colors[jj-1,ii]**((LL/40)**2),
                label = '{} km, {}'.format(LL, opt.upper()),
            )
for ax in axs:
    ax.set_xlim([4, 5e3])
    ax.set_ylim([1e-25, 2.5e-23])
    ax.xaxis.set_major_formatter(mpl.ticker.FuncFormatter(lambda y, _: '{:g}'.format(y)))
    ax.set_xlabel('Frequency / Hz')
    ax.set_ylabel('Strain noise / Hz$^{-1/2}$')
    ax.legend(ncol=2, handlelength=2)
h1.savefig('ce1_alternate_strains.pdf')
h2.savefig('ce2_alternate_strains.pdf')
